@@ -142,7 +142,6 @@ describe 'horizon' do
           :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
-          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -152,7 +151,6 @@ describe 'horizon' do
           "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
-          "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           'SESSION_COOKIE_HTTPONLY = True',
@@ -217,11 +215,9 @@ describe 'horizon' do
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           "OVERVIEW_DAYS_RANGE = 1",
-          'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
-      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
@@ -582,16 +578,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with disallow iframe embed disabled' do
+    context 'with disallow iframe embed enabled' do
       before do
         params.merge!({
-                        :disallow_iframe_embed => false
+                        :disallow_iframe_embed => true
                       })
       end
 
       it 'disallow_iframe_embed is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'DISALLOW_IFRAME_EMBED = False',
+                                          'HORIZON_CONFIG["disallow_iframe_embed"] = True',
                                         ])
       end
     end
@@ -758,7 +754,6 @@ describe 'horizon' do
         when 'Debian'
           if facts[:os_package_type] == 'debian'
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard-apache',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -766,7 +761,6 @@ describe 'horizon' do
             }
           else
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -776,7 +770,6 @@ describe 'horizon' do
         when 'RedHat'
           if facts[:operatingsystem] == 'Fedora'
             { :config_file      => '/etc/openstack-dashboard/local_settings',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/dashboard',
               :root_path        => '/usr/share/openstack-dashboard',
@@ -785,7 +778,6 @@ describe 'horizon' do
           else
             if facts[:operatingsystemmajrelease] > '7'
               { :config_file      => '/etc/openstack-dashboard/local_settings',
-                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
                 :package_name     => 'openstack-dashboard',
                 :root_url         => '/dashboard',
                 :root_path        => '/usr/share/openstack-dashboard',
@@ -793,7 +785,6 @@ describe 'horizon' do
               }
             else
               { :config_file      => '/etc/openstack-dashboard/local_settings',
-                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
                 :package_name     => 'openstack-dashboard',
                 :root_url         => '/dashboard',
                 :root_path        => '/usr/share/openstack-dashboard',
